@@ -22,17 +22,21 @@ import numpy as np
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, algo=None, aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon',number_per_year=252):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, selected_algo=None, aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon',number_per_year=252):
         super().__init__()
+        self.starting_date = starting_date
+        self.running_date = running_date
         self.aggregated_pkl_file_suffix=aggregated_pkl_file_suffix
         self.aggregated_pkl_mapping_file_suffix=aggregated_pkl_mapping_file_suffix
         self.underlying = underlying
         self.list_pkl_file_suffix = list_pkl_file_suffix
         self.frequence=frequence
-        self.algo=algo
-        self.list_pkl_file_name = self.underlying + '_' + self.frequence + '_' + self.algo + self.list_pkl_file_suffix
-        self.aggregated_pkl_file_name = self.underlying + '_' + self.frequence + '_' + self.algo + self.aggregated_pkl_file_suffix
-        self.aggregated_pkl_mapping_file_name = self.underlying + '_' + self.frequence + '_' + self.algo + self.aggregated_pkl_mapping_file_suffix
+        self.selected_algo=selected_algo
+        self.dates_stub = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y')
+        self.list_pkl_file_name = self.dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
+        self.aggregated_pkl_file_name = self.dates_stub +'_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
+        self.aggregated_pkl_mapping_file_name = self.dates_stub +'_'+ self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
+
         self.local_root_directory=local_root_directory
         self.user=user
         self.dropbox_backup = dropbox_backup
@@ -83,7 +87,8 @@ class ForecasterRunner(AbstractRunner):
         print(raw_data.shape)
 
 #        X, y = raw_data.loc[:, raw_data.columns != 'target'], raw_data['target']
-        y = raw_data['close'].pct_change()
+        raw_data['close_return'] = raw_data['close'].pct_change()
+        y = raw_data['close_return']
         X = raw_data[[col for col in raw_data.columns if 'signal' in col]]
 
         print('predictors shape')
