@@ -11,17 +11,14 @@ from napoleontoolbox.utility import metrics
 from napoleontoolbox.signal import signal_generator
 from napoleontoolbox.signal import signal_utility
 
-import json
-
-
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, freqly_pkl_file_name_sufffix='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',period=252):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, freqly_pkl_file_name_suffix='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',period=252):
         super().__init__()
-        self.freqly_pkl_file_name_sufffix=freqly_pkl_file_name_sufffix
+        self.freqly_pkl_file_name_suffix=freqly_pkl_file_name_suffix
         self.underlying = underlying
         self.local_root_directory=local_root_directory
-        self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_pkl_file_name_sufffix
+        self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_pkl_file_name_suffix
         self.user=user
         self.dropbox_backup = dropbox_backup
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
@@ -76,7 +73,7 @@ class SimpleSignalRunner(AbstractRunner):
                 return
 
 
-        freqly_df = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
+        freqly_df, _ = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
         sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.period, from_ret=True)
         sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= self.period, from_ret=True)
         freqly_df = freqly_df.dropna()
