@@ -225,7 +225,7 @@ def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, ke
     return kpis_df, data, hr_dic, json_dic
 
 
-def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False):
+def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False, recompute_return=True):
     if normalization:
         #data.signal = (data.signal - data.signal.mean())/data.signal.std(ddof=0)
         data.signal = expanding_zscore(signal_np_array=data.signal.values)
@@ -234,8 +234,8 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     if print_turnover:
         print('average freqly turn over')
         print(average_turn_over)
-
-    data['close_return'] = data['close'].pct_change()
+    if recompute_return:
+        data['close_return'] = data['close'].pct_change()
     data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
     data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
     if transaction_cost :
@@ -361,10 +361,10 @@ def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnov
     signals_returns_df = None
     for sig in results_df.columns:
         if 'signal' in sig:
-            temp_df = results_df[['close', sig]].copy()
+            temp_df = results_df[['close_return', sig]].copy()
             temp_df = temp_df.rename(columns={sig: "signal"}, errors="raise")
             freqly_df, _ = signal_utility.reconstitute_signal_perf(data=temp_df, transaction_cost=transac_cost,
-                                                                   print_turnover=print_turnover)
+                                                                   print_turnover=print_turnover, recompute_return=False)
             if signals_returns_df is None:
                 signals_returns_df = freqly_df[['perf_return']].rename(columns={'perf_return': sig})
             else:
